<?php
 
/**
 * Clock Plugin: Show realtime clock
 * 
 * @file       clock/syntax.php
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     'Ryan Chappelle' <visuallucho_plusplus at yahoo dot es>
 * @brief      Show a clock in wikipage
 * @version    0.9
 *
 *  This plugin is **experimental**. Its purpose
 *  is to display a realtime clock using JavaScript and CSS.
 *
 *  For a live test point a decent web browser (ie.. not IE, 
 *  pun intended) to my homepage.
 *
 *  Greetings.
 *        - ryan.chappelle
 */


if(!defined('DW_LF')) define('DW_LF',"\n");
 
if(!defined('DOKU_INC')) 
define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) 
define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 
/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_clock extends DokuWiki_Syntax_Plugin {
 
    /**
     * return some info
     */
    function getInfo(){
        return array(
            'author' => 'ryan.chappelle',
            'email'  => 'visuallucho_plusplus@yahoo.es',
            'date'   => '2008-09-20',
            'name'   => 'Clock Plugin',
            'desc'   => 'Shows a JavaScript-based clock',
            'url'    => 'http://wiki.splitbrain.org/plugin:clock',
        );
    }
 
    /**
     * What kind of syntax are we?
     */
    function getType(){
        return 'substition';
    }
 
    /**
     * What can we Do?
     */
    //function getAllowedTypes() { 
    //    return array(); 
    //}
 
    /**
     * Where to sort in?
     */
    function getSort(){
        return 299;
    }
 
    /**
     * What's our code layout?
     */    
    function getPType(){ 
        return 'normal'; 
    }
 
    /**
     * How do we get to the lexer?
     */
    function connectTo($mode) {
         $this->Lexer->addSpecialPattern (
         '\{\{clock\}\}', $mode, 'plugin_clock');
 
    }
 
    /**
     * Handle the match
     */
    function handle($match, $state, $pos, &$handler){
 
        $data= array();
        /** 
         * Right now no handling is implemented.
         * For the release version, configuration options will be
         * read here (from $this->getConf) and parsed for 
         * display options.
         */

        /* Are we ready yet? */

        return $data;
    }  
 
    /**
     * Create output
     * Right now rendering is as simple as it can get.
     * For the release version, CSS styling and data/id fallbacks
     * will be implemented.
     */
    function render($mode, &$renderer, $data) {
        if($mode == 'xhtml'){
            $renderer->doc .= $this->_clock_createblock_html($data);
            return true;
        }
        /* That's all about rendering that needs to be done, at the moment */
        return false;
    }


    /**
     * From this point onwards, local (helper) functions are implemented
     */


    /** 
     * @fn          dw_clock_object_ID
     * @brief       returns the in-code ID for the clock object
     *  This function sets the name used for the ID of the clock object.
     */
    function _get_clock_object_ID () {
        return 'dw_clock_object';
        }

    /**
     * @fn          _clock_createblock_html
     * @brief       Creates the HTML code for the clock object.
     */
    function _clock_createblock_html($data) {
        $theStyle   = 'default';
        $theID      = $this->_get_clock_object_ID();

        $codetext.= '<div id="'. $theID. '" class="'. $theStyle. '">';
        $codetext.= '<div id="clock_face" class="face">hh:mm:ss</div>'. DW_LF;

        $codetext.= '</div>'. DW_LF;
        return $codetext;
     }
 
}


 
/*?> */

